use super::create_vram_bg;
use super::main_tab::SharedMainTab;
use super::MainWindowRef;
use super::{file_tab::{FileTab, SharedFileTab}, main_tab::MainTab};
use std::{rc::Rc, sync::Mutex};
use tim_tool::logic::TIMManager;

pub type MutexTIMManager = Rc<Mutex<TIMManager>>;

pub struct GUIElements {
    _file_tab: SharedFileTab,
    _main_tab: SharedMainTab,
}

impl GUIElements {
    pub fn new(main_window: MainWindowRef, tim_manager: MutexTIMManager) -> Result<GUIElements, slint::PlatformError> {
        main_window.borrow().set_main_tab_vram_bg(GUIElements::create_bg()?);

        let _main_tab = MainTab::new(main_window.clone(), tim_manager.clone());
        let _file_tab = FileTab::new(main_window.clone(), _main_tab.clone(), tim_manager);
        
        Ok(GUIElements{_file_tab, _main_tab})
    }

    fn create_bg() -> Result<slint::Image, slint::PlatformError> {
        Ok(slint::Image::from_rgba8_premultiplied(create_vram_bg(320, 256).ok_or(slint::PlatformError::Other("Failed creating VRAM background image".to_string()))?))
    }
}